==> gtk-gnutella-0.96.tar.bz2: gtk-gnutella-0.96/src/lib/adns.h <==
/*
 * $Id: adns.h,v 1.6 2005/08/17 13:44:05 cbiere Exp $
 *
 * Copyright (c) 2003, Christian Biere
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup lib
 * @file
 *
 * Asynchronous DNS lookup.
 *
 * @author Christian Biere
 * @date 2003
 */

#ifndef _adns_h_
#define _adns_h_

#include <glib.h>
#include "host_addr.h"	/* For ``struct host_addr'' */

typedef void (*adns_callback_t)(const host_addr_t *, gpointer);
typedef void (*adns_reverse_callback_t)(const gchar *, gpointer);

void adns_init(void);
gboolean adns_resolve(const gchar *, adns_callback_t, gpointer);
gboolean adns_reverse_lookup(const host_addr_t,
		adns_reverse_callback_t, gpointer);
void adns_close(void);

#endif /* _adns_h_ */

==> gtk-gnutella_0.97.1.orig.tar.bz2: gtk-gnutella-0.97.1/src/lib/adns.h <==
/*
 * Copyright (c) 2003, Christian Biere
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup lib
 * @file
 *
 * Asynchronous DNS lookup.
 *
 * @author Christian Biere
 * @date 2003
 */

#ifndef _adns_h_
#define _adns_h_

#include "common.h"
#include "host_addr.h"	/* For ``struct host_addr'' */

typedef void (*adns_callback_t)(const host_addr_t *, size_t, gpointer);
typedef void (*adns_reverse_callback_t)(const char *, gpointer);

void adns_init(void);
gboolean adns_resolve(const char *, enum net_type net,
	adns_callback_t, gpointer);
gboolean adns_reverse_lookup(const host_addr_t,
	adns_reverse_callback_t, gpointer);
void adns_close(void);

#endif /* _adns_h_ */
